\name{cv.tree}
\title{Cross-validation for Choosing Tree Complexity}
\usage{
cv.tree(object, rand, FUN = prune.tree, K = 10, ...)
}
\alias{cv.tree}
\arguments{
  \item{object}{An object of class \code{"tree"}.}
  \item{rand}{Optionally an integer vector of the length the number of
    cases used to create \code{object}, assigning the cases to different
    groups for cross-validation.}
  \item{FUN}{The function to do the pruning.}
  \item{K}{The number of folds of the cross-validation.}
  \item{\dots}{Additional arguments to \code{FUN}.}
}
\description{
  Runs a K-fold cross-validation experiment to find the deviance or
  number of misclassifications as a function of the cost-complexity
  parameter \code{k}.
}
\value{
  A copy of \code{FUN} applied to \code{object}, with component
  \code{dev} replaced by the cross-validated results from the
  sum of the \code{dev} components of each fit.
}
\author{B. D. Ripley}

\seealso{\code{\link{tree}}, \code{\link{prune.tree}}}

\examples{
library(MASS)
data(cpus)
cpus.ltr <- tree(log10(perf) ~ syct + mmin + mmax + cach
     + chmin + chmax, data=cpus)
cv.tree(cpus.ltr, , prune.tree)
}
\keyword{tree}

\eof
\name{deviance.tree}
\alias{deviance.tree}
\alias{deviance.singlenode}
\title{Extract Deviance from a Tree Object}
\description{
  Extract deviance from a tree object.
}
\usage{
\method{deviance}{tree}(object, detail = FALSE, \dots)
}
\arguments{
 \item{object}{an object of calls \code{"tree"}}
 \item{detail}{logical. If true, returns a vector of deviance
   contributions from each node.}
 \item{\dots}{argumens to be passed to or from other methods.}
}
\value{
  The overall deviance, or a vector of contributions from the cases
  at each node. The overall deviance is the sum over leaves in the
  latter case.
}
\keyword{tree}

\eof
\name{misclass.tree}
\title{Misclassifications by a Classification Tree}
\usage{
misclass.tree(tree, detail = FALSE)
}
\alias{misclass.tree}
\arguments{
  \item{tree}{Object of class \code{"tree"}, representing a
    classification tree.}
  \item{detail}{If false, report overall number of
    mis-classifications. If true, report the number at each node.}
}
\description{
  Report the number of mis-classifications made by a classification
  tree, either overall or at each node.
}
\details{
  The quantities returned are weighted by the observational weights if
  these are supplied in the construction of \code{tree}.
}
\value{
  Either the overall number of misclassifications or the number for each node.
}
\author{B. D. Ripley}
\seealso{\code{\link{tree}}}

\examples{
data(iris)
ir.tr <- tree(Species ~., iris)
misclass.tree(ir.tr)
misclass.tree(ir.tr, detail=TRUE)
}
\keyword{tree}

\eof
\name{na.tree.replace}
\alias{na.tree.replace}
\title{
  Replace 'NA's in Predictor Variables
}
\description{
  Adds a new level called \code{"NA"} to any discrete predictor in
  a data frame that contains \code{NA}s.  Stops if any continuous
  predictor contains an \code{NA}.
}
\usage{
na.tree.replace(frame)
}
\arguments{
\item{frame}{
  data frame used to grow a tree.
}}
\value{
  data frame such that a new level named \code{"NA"} is added to
  any discrete predictor in \code{frame} with \code{NA}s.
}
\details{
  This function is used via the \code{na.action} argument to \code{tree}.
}
\seealso{
  \code{\link{tree}}, \code{\link{na.omit}}.
}
\keyword{tree}

\eof
\name{partition.tree}
\title{Plot the Partitions of a simple Tree Model}
\usage{
partition.tree(tree, label = "yval", add = FALSE, ordvars, ...)
}
\alias{partition.tree}
\description{
  Plot the partitions of a tree involving one or two variables.
}
\arguments{
  \item{tree}{A object of class \code{"tree"}.}
  \item{label}{A character string giving the column of the frame
    component of \code{tree} to be used to label the regions.}
  \item{add}{If true, add to existing plot, otherwise start a new plot.}
  \item{ordvars}{The ordering of the variables to be used in a 2D
    plot. Specify the names in a character string of length 2; the first
    will be used on the \code{x} axis.}
  \item{\dots}{Graphical parameters.}
}
\details{
  This can be used with a regression or classification tree containing
  one or two continuous predictors (only).
  
  If the tree contains one predictor, the predicted value (a regression
  tree) or the probability of the first class (a classification tree) is
  plotted against the predictor over its range in the training set.

  If the tree contains two predictors, a plot is made of the space
  covered by those two predictors and the partition made by the tree is
  superimposed. 
}
\value{
  None.
}
\author{B. D. Ripley}
\seealso{\code{\link{tree}}}

\examples{
data(iris)
ir.tr <- tree(Species ~., iris)
ir.tr
ir.tr1 <- snip.tree(ir.tr, nodes = c(12, 7))
summary(ir.tr1)
par(pty = "s")
plot(iris[, 3],iris[, 4], type="n",
     xlab="petal length", ylab="petal width")
text(iris[, 3], iris[, 4], c("s", "c", "v")[iris[, 5]])
partition.tree(ir.tr1, add = TRUE, cex = 1.5)

# 1D example
ir.tr <- tree(Petal.Width ~ Petal.Length, iris)
plot(iris[,3], iris[,4], type="n", xlab="Length", ylab="Width")
partition.tree(ir.tr, add = TRUE, cex = 1.5)
}
\keyword{tree}
\keyword{hplot}

\eof
\name{plot.tree}
\alias{plot.tree}
\title{Plot a Tree Object}
\description{
  Plot a tree object on the current graphical device
}
\usage{
\method{plot}{tree}(x, y = NULL, type = c("proportional", "uniform"), ...)
}
\arguments{
 \item{x}{an object of class \code{"tree"}.}
 \item{y}{ignored. Used for positional matching of \code{type}.}
 \item{type}{character string. If this partially matches
   \code{"uniform"}, the branches are of uniform
   length. Otherwise they are proportional to the decrease in impurity.}
 \item{\dots}{graphical parameters.}
}
\value{
  An (invisible) list with components \code{x} and \code{y}
  giving the coordinates of the tree nodes.

  As a side effect, the value of \code{type == "uniform"} is stored in
  the variable \code{.Tree.unif.?} in the global environment, where \code{?}
  is the device number.
}
\author{B. D. Ripley}


\seealso{\code{\link{tree}}}
\keyword{tree}
\keyword{hplot}

\eof
\name{plot.tree.sequence}
\alias{plot.tree.sequence}
\title{
  Plot a Tree Sequence
}
\description{
  Allows the user to plot a tree sequence.
}
\usage{
\method{plot}{tree.sequence}(x, \dots, order = c("increasing", "decreasing"))
}
\synopsis{
plot.tree.sequence(x, ..., type = "l", ylim = range(x$dev),
    order. = c("increasing", "decreasing"))
}
\arguments{
  \item{x}{object of class \code{tree.sequence}.
    This is assumed to be the result of some function that produces
    an object with the same named components (\code{size},
    \code{deviance}, \code{k})
    as that returned by \code{prune.tree()}.}
  \item{order}{
    of \code{size} on the plot.  Use \code{"decreasing"} for
    the natural ordering of \code{k}
    and the amount of pruning. Only the first character is needed.
    }
  \item{\dots}{graphical parameters.
  }
}
\section{Side Effects}{
  Plots deviance or number of misclassifications (or total loss)
  versus size for a sequence of trees.
}
\details{
  This function is a method for the generic function
  \code{plot()} for class \code{tree.sequence}.
  It can be invoked by calling \code{plot(x)} for an
  object \code{x} of the appropriate class, or directly by
  calling \code{plot.tree.sequence(x)} regardless of the
  class of the object.
}
\examples{
library(MASS)
data(cpus)
cpus.ltr <- tree(log(perf) ~ syct + mmin + mmax + cach + chmin + chmax,
                 data = cpus)
plot(prune.tree(cpus.ltr))
}
\keyword{tree}

\eof
\name{predict.tree}
\alias{predict.tree}
\title{
Predictions from a Fitted Tree Object
}
\description{
  Returns a vector of predicted responses from a fitted tree object.
}
\usage{
\method{predict}{tree}(object, newdata = list(),
        type = c("vector", "tree", "class", "where"), 
        split = FALSE, nwts, eps = 1e-3, ...)
}
\arguments{
\item{object}{
  fitted model object of class \code{tree}.  This is assumed to be the result
  of some function that produces an object with the same named
  components as that returned by the \code{tree} function.
}
\item{newdata}{
  data frame containing the values at which predictions are required.
  The predictors referred to in the right side
  of \code{formula(object)} must be present by name in \code{newdata}.
  If missing, fitted values are returned.
}
\item{type}{
  character string denoting whether the predictions are
  returned as a vector (default) or as a tree object.
}
\item{split}{
  governs the handling of missing values. If false, cases with missing
  values are dropped down the tree until a leaf is reached or a node
  for which the attribute is missing, and that node is used for
  prediction. If \code{split = TRUE} cases with missing attributes are
  split into fractional cases and dropped down each side of the split.
  The predicted values are averaged over the fractions to give the
  prediction.
}
\item{nwts}{
  weights for the \code{newdata} cases, used when predicting a tree.
}
\item{eps}{
  a lower bound for the probabilities, used if events of predicted
  probability zero occur in \code{newdata} when predicting a tree.
}
\item{\dots}{further arguments passed to or from other methods.}
}
\value{
  If \code{type = "vector"}:
  vector of predicted responses or, if the response is a factor, matrix
  of predicted class probabilities.  This new object is obtained by
  dropping \code{newdata} down \code{object}.  For factor predictors, if an
  observation contains a level not used to grow the tree, it is left at
  the deepest possible node and \code{frame$yval} or \code{frame$yprob} at that
  node is the prediction.
  

  If \code{type = "tree"}:
  an object of class \code{"tree"} is returned with new values
  for \code{frame$n} and \code{frame$dev}. If
  \code{newdata} does not contain a column for the response in the formula
  the value of \code{frame$dev} will be \code{NA}, and if some values in the
  response are missing, the some of the deviances will be \code{NA}.


  If \code{type = "class"}:
  for a classification tree, a factor of the  predicted classes (that
  with highest posterior probability, with ties split randomly).

  If \code{type = "where"}:
  the nodes the cases reach.
}
\details{
  This function is a method for the generic function
  \code{predict()} for class \code{tree}.
  It can be invoked by calling \code{predict(x)} for an
  object \code{x} of the appropriate class, or directly by
  calling \code{predict.tree(x)} regardless of the
  class of the object.
}
\references{
Ripley, B. D. (1996).
\emph{Pattern Recognition and Neural Networks.}
Cambridge University Press, Cambridge. Chapter 7.
}
\seealso{
  \code{\link{predict}}, \code{\link{tree}}.
}
\examples{
data(shuttle, package="MASS")
shuttle.tr <- tree(use ~ ., shuttle, subset=1:253,
                   mindev=1e-6, minsize=2)
shuttle.tr
shuttle1 <- shuttle[254:256, ]  # 3 missing cases
predict(shuttle.tr, shuttle1)
}
\keyword{tree}

\eof
\name{prune.tree}
\alias{prune.tree}
\alias{prune.misclass}
\title{
Cost-complexity Pruning of Tree Object
}
\description{
  Determines a nested sequence of subtrees of the supplied tree by
  recursively "snipping" off the least important splits.
}
\usage{
prune.tree(tree, k = NULL, best = NULL, newdata, nwts,
           method = c("deviance", "misclass"), loss, eps = 1e-3)
prune.misclass(tree, k = NULL, best = NULL, newdata, 
               nwts, loss, eps = 1e-3)
}
\synopsis{
prune.tree(tree, k = NULL, best = NULL, newdata, nwts,
           method = c("deviance", "misclass"), loss, eps = 1e-3)
prune.misclass(tree, ...)
}
\arguments{
  \item{tree}{
    fitted model object of class \code{tree}.  This is assumed to be the result
    of some function that produces an object with the same named
    components as that returned by the \code{tree()} function.
  }
  \item{k}{
    cost-complexity parameter defining either a specific subtree of \code{tree}
    (\code{k} a scalar) or the (optional) sequence of subtrees minimizing the
    cost-complexity measure (\code{k} a vector). If missing, \code{k} is
    determined algorithmically.
  }
  \item{best}{
    integer requesting the size (i.e. number of terminal nodes) of a
    specific subtree in the cost-complexity sequence to be returned. This
    is an alternative way to select a subtree than by supplying a scalar
    cost-complexity parameter \code{k}.  If there is no tree in the sequence of
    the requested size, the next largest is returned.
  }
  \item{newdata}{
    data frame upon which the sequence of cost-complexity subtrees is
    evaluated.  If missing, the data used to grow the tree are used.
  }
  \item{nwts}{
    weights for the \code{newdata} cases.
  }
  \item{method}{
    character string denoting the measure of node heterogeneity used to
    guide cost-complexity pruning.  For regression trees, only the
    default, \code{deviance}, is accepted.  For classification trees, the
    default is \code{deviance} and the alternative is \code{misclass}
    (number of misclassifications or total loss).
  }
  \item{loss}{
    a matrix giving for each true class (row) the numeric loss of
    predicting the class (column).  The classes should be in the order of
    the levels of the response.  It is conventional for a loss matrix to
    have a zero diagonal.  The default is 0--1 loss.
  }
  \item{eps}{
    a lower bound for the probabilities, used to compute deviances if
    events of predicted probability zero occur in \code{newdata}.
  }
}
\details{
  Determines a nested sequence of subtrees of the supplied tree by
  recursively "snipping" off the least important splits, based upon
  the cost-complexity measure.  \code{prune.misclass} is an abbreviation for
  \code{prune.tree(method = "misclass")} for use with \code{cv.tree}.
  
  If \code{k} is supplied, the optimal subtree for that value is returned.

  The response as well as the predictors referred to in the right side
  of the formula in \code{tree} must be present by name in
  \code{newdata}. These data are dropped down each tree in the
  cost-complexity sequence and deviances or losses calculated by
  comparing the supplied response to the prediction.  The function
  \code{\link{cv.tree}()} routinely uses the \code{newdata} argument
  in cross-validating the pruning procedure.  A \code{plot} method
  exists for objects of this class.  It displays the value of the
  deviance, the number of misclassifications or the total loss for
  each subtree in the cost-complexity sequence.  An additional axis
  displays the values of the cost-complexity parameter at each subtree.
}
\value{
  If \code{k} is supplied and is a scalar, a \code{tree} object is
  returned that minimizes the cost-complexity measure for that \code{k}.
  If \code{best} is supplied, a \code{tree} object of size \code{best}
  is returned.  Otherwise, an object of class \code{tree.sequence}
  is returned.  The object contains the following components:

  \item{size}{
    number of terminal nodes in each tree in the cost-complexity pruning
    sequence.
  }
  \item{deviance}{
    total deviance of each tree in the cost-complexity pruning sequence.
  }
  \item{k}{
    the value of the cost-complexity pruning parameter of each tree in 
    the sequence.
  }
}
\examples{
library(MASS)
data(fgl)
fgl.tr <- tree(type ~ ., fgl)
plot(print(fgl.tr))
fgl.cv <- cv.tree(fgl.tr,, prune.tree)
for(i in 2:5)  fgl.cv$dev <- fgl.cv$dev +
   cv.tree(fgl.tr,, prune.tree)$dev
fgl.cv$dev <- fgl.cv$dev/5
plot(fgl.cv)
}
\keyword{tree}

\eof
\name{snip.tree}
\title{Snip Parts of Tree Objects}
\usage{
snip.tree(tree, nodes, xy.save = FALSE, digits = getOption("digits") - 3)
}
\alias{snip.tree}
\arguments{
  \item{tree}{An object of class \code{"tree"}.}
  \item{nodes}{An integer vector giving those nodes that are the roots of
    sub-trees to be snipped off. If missing, the user is invited to
    select a node at which to snip.}
  \item{xy.save}{If true, the \code{x} and \code{y} coordinates selected
    interactively are saved in the object \code{.xy} in the global
    environment.}
  \item{digits}{Precision used in printing statistics for selected nodes.}
}
\description{
  \code{snip.tree} has two related functions. If \code{nodes} is
  supplied, it removes those nodes and all their descendants from the
  tree.

  If \code{nodes} is not supplied, the user is invited to select
  nodes interactively; this makes sense only if the tree has already been
  plotted. A node is selected by clicking with the left mouse button;
  its number and
  the deviance of the current tree and that which would remain if that
  node were removed are printed. Selecting the same node again causes it
  to be removed (and the lines of its sub-tree erased).
  Clicking any other button terminates the selection process.
}
\value{
  A tree object containing the nodes that remain after
  specified or selected subtrees have been snipped off.
}
\author{B. D. Ripley}
\seealso{\code{\link{tree}}, \code{\link{prune.tree}}.}

\keyword{tree}

\eof
\name{text.tree}
\alias{text.tree}
\title{Annotate a Tree Plot}
\description{
  Add text to a tree plot.
}
\usage{
\method{text}{tree}(x, splits = TRUE, label = "yval", all = FALSE,
     pretty = NULL, digits = getOption("digits") - 3, ...)
}
\synopsis{
text.tree(x, splits = TRUE, label = "yval", all = FALSE,
          pretty = NULL, digits = getOption("digits") - 3,
          adj = par("adj"), xpd = TRUE, ...)
}
\arguments{
 \item{x}{an object of class \code{"tree"}}
 \item{splits}{logical. If \code{TRUE} the splits are labelled}
 \item{label}{The name of column in the \code{frame} component of
   \code{x}, to be used to label the nodes. Can be \code{NULL} to
   suppress node-labelling}
 \item{all}{logical. By default, only the leaves are labelled, but if
   true interior nodes are also labelled.}
 \item{pretty}{the manipulation used for split labels involving
   attributes. See Details.}
 \item{digits}{significant digits for numerical labels.}
 \item{\dots}{graphical parameters such as \code{cex} and \code{font}.}
}
\details{
  If \code{pretty = 0} then the level names of a factor split attributes
  are used unchanged.  If \code{pretty = NULL}, the levels are presented
  by \code{a}, \code{b}, \dots.  If \code{pretty} is a positive integer,
  \code{\link{abbreviate}} is applied to the labels with that value
  for its argument \code{minlength}.

  If the lettering is vertical (par \code{srt = 90}) and \code{adj} is
  not supplied it is adjusted appropriately.
}
\value{
  None.
}
\author{B. D. Ripley}

\seealso{\code{\link{plot.tree}}}
\example{
data(iris)
ir.tr <- tree(Species ~., iris)
plot(ir.tr)
text(ir.tr)
}
\keyword{tree}
\keyword{hplot}

\eof
\name{tile.tree}
\title{Add Class Barplots to a Classification Tree Plot}
\usage{
tile.tree(tree, var, screen.arg = ascr + 1, axes = TRUE)
}
\alias{tile.tree}
\arguments{
  \item{tree}{fitted object of class \code{"tree"}.}
  \item{var}{a factor variable to be displayed: by default it is the
    repsonse factor of the tree.}
  \item{screen.arg}{The screen to be used: default the next after the
    currently active screen.}
  \item{axes}{logical flag for drawing of axes for the barplots.}
}
\description{
  The computes a the frequencies of level of \code{var} for cases
  reaching each leaf of the tree, and plots of barchart of the set of
  frequencies underneath each leaf.
}
\value{
  A matrix of counts of categories (rows) for each leaf (columns). The
  principal effect is the plot.
}
\author{B. D. Ripley}

\seealso{\code{\link{tree.screens}}}

\examples{
library(MASS)
data(fgl)
fgl.tr <- tree(type ~ ., fgl)
summary(fgl.tr)
plot(fgl.tr);  text(fgl.tr, all=TRUE, cex=0.5)
fgl.tr1 <- snip.tree(fgl.tr, node=c(108, 31, 26))
tree.screens()
plot(fgl.tr1)
text(fgl.tr1)
tile.tree(fgl.tr1, fgl$type)
close.screen(all = TRUE)
}
\keyword{tree}
\keyword{hplot}

\eof
\name{tree-internal}
\alias{labels.tree}
\alias{model.frame.tree}
\title{Internal Functions Used by the 'tree' Package}
\description{
  Internal functions used in the \pkg{tree} package.
}
\usage{
\method{labels}{tree}(object, pretty = TRUE, collapse = TRUE, \dots)

\method{model}{frame.tree}(formula, \dots)
}
\note{These are not intended for use by end users.}
\keyword{internal}

\eof
\name{tree}
\title{Fit a Classification or Regression Tree}
\usage{
tree(formula, data, weights, subset,
     na.action = na.pass, control = tree.control(nobs, ...),
     method = "recursive.partition",
     split = c("deviance", "gini"),
     model = FALSE, x = FALSE, y = TRUE, wts = TRUE, ...)
}
\alias{tree}
\alias{print.tree}
\alias{summary.tree}
\alias{print.summary.tree}
\alias{residuals.tree}
\description{
  A tree is grown by binary recursive partitioning using the response in
  the specified formula and choosing splits from the terms of the
  right-hand-side.
}
\arguments{
  \item{formula}{A formula expression. The left-hand-side (response)
    should be either a numerical vector when a regression tree will be
    fitted or a factor, when a classification tree is produced. The
    right-hand-side should be a series of numeric or factor
    variables separated by \code{+}; there should be no interaction
    terms. Both \code{.} and \code{-} are allowed: regression trees can
    have \code{offset} terms.}
  \item{data}{A data frame in which to preferentially interpret
    \code{formula}, \code{weights} and \code{subset}.}
  \item{weights}{Vector of non-negative observational weights; fractional
    weights are allowed.}
  \item{subset}{An expression specifying the subset of cases to be used.}
  \item{na.action}{A function to filter missing data from the model
    frame. The default is \code{na.pass} (to do nothing) as \code{tree}
    handles missing values (by dropping them down the tree as far
    as possible).}
  \item{control}{A list as returned by \code{tree.control}.}
  \item{method}{character string giving the method to use. The only other
    useful value is \code{"model.frame"}.}
  \item{split}{Splitting criterion to use.}
  \item{model}{If this argument is itself a model frame, then the
    \code{formula} and \code{data} arguments are ignored, and
    \code{model} is used to define the model.  If the argument is
    logical and true, the model frame is stored as component
    \code{model} in the result.}
  \item{x}{logical. If true, the matrix of variables for each case
    is returned.}
  \item{y}{logical. If true, the response variable is returned.}
  \item{wts}{logical. If true, the weights are returned.}
  \item{\dots}{Additional arguments that are passed to
    \code{tree.control}. Normally used for \code{mincut}, \code{minsize}
    or \code{mindev}.}
}
\details{
  A tree is grown by binary recursive partitioning using the response in
  the specified formula and choosing splits from the terms of the
  right-hand-side. Numeric variables are divided into
  \eqn{X < a} and \eqn{X > a}; the levels of an unordered factor
  are divided into
  two non-empty groups. The split which maximizes the reduction in
  impurity is chosen, the data set split and the process
  repeated. Splitting continues until the terminal nodes are too small or
  too few to be split.

  Tree growth is limited to a depth of 31 by the use of integers to
  label nodes.

  Factor predictor variables can have up to 32 levels. This limit is
  imposed for ease of labelling, but since their use in a classification
  tree with three or more levels in a response involves a search over
  \eqn{2^{(k-1)}-1}{2^(k-1) - 1} groupings for \eqn{k} levels,
  the practical limit is much less.
}
\value{
  The value is an object of class \code{"tree"} which has components
  \item{frame}{A data frame with a row for each node, and
    \code{row.names} giving the node numbers. The columns include
    \code{var}, the variable used at the split (or \code{"<leaf>"} for a
    terminal node), \code{n}, the (weighted) number of cases reaching
    that node, \code{dev} the deviance of the node, \code{yval}, the
    fitted value at the node (the mean for regression trees, a majority
    class for classification trees) and \code{split}, a two-column
    matrix of the labels for the left and right splits at the
    node. Classification trees also have \code{yprob}, a matrix of
    fitted probabilities for each response level.}
  \item{where}{An integer vector giving the row number of the frame
    detailing the node to which each case is assigned.}
  \item{terms}{The terms of the formula.}
  \item{call}{The matched call to \code{Tree}.}
  \item{model}{If \code{model = TRUE}, the model frame.}
  \item{x}{If \code{x = TRUE}, the model matrix.}
  \item{y}{If \code{y = TRUE}, the response.}
  \item{wts}{If \code{wts = TRUE}, the weights.}
  and attributes \code{xlevels} and, for classification trees,
  \code{ylevels}.

  A tree with no splits is of class \code{"singlenode"} which inherits
  from class \code{"tree"}.
}
\references{
  Breiman L., Friedman J. H., Olshen R. A., and  Stone,  C. J. (1984)
  \emph{Classification  and Regression Trees.}  Wadsworth.

  Ripley, B. D. (1996)
  \emph{Pattern Recognition and Neural Networks.}
  Cambridge University Press, Cambridge. Chapter 7.
}
\author{B. D. Ripley}


\seealso{\code{\link{tree.control}}, \code{\link{prune.tree}},
   \code{\link{predict.tree}}, \code{\link{snip.tree}}}

\examples{
library(MASS)
data(cpus)
cpus.ltr <- tree(log10(perf) ~ syct+mmin+mmax+cach+chmin+chmax, cpus)
cpus.ltr
summary(cpus.ltr)
plot(cpus.ltr);  text(cpus.ltr)

data(iris)
ir.tr <- tree(Species ~., iris)
ir.tr
summary(ir.tr)
\dontshow{
## tests of singlenode tree
set.seed(1)
Nvars <- 4;
Nsamples <- 5
N <- Nvars*Nsamples;
dat <- matrix(sample(1:2, N, c(0.5,0.5), replace=TRUE), Nsamples, Nvars)
dat <- as.data.frame(dat)
for (i in 1:Nvars) {
   dat[,i]<- factor(dat[,i], 1:2)
}
names(dat) <- c(paste("X", 1:3, sep=""), "Y")
tr <- tree(Y ~ ., dat)
tr
summary(tr)
deviance(tr)
residuals(tr)
}}
\keyword{tree}

\eof
\name{tree.control}
\title{Select Parameters for Tree}
\usage{
tree.control(nobs, mincut = 5, minsize = 10, mindev = 0.01)
}
\alias{tree.control}
\arguments{
  \item{nobs}{The number of observations in the training set.}
  \item{mincut}{The minimum number of observations to include in either
    child node. This is a weighted quantity; the observational weights are used
    to compute the \sQuote{number}. The default is 5.}
  \item{minsize}{The smallest allowed node size: a weighted quantity. The
    default is 10.}
  \item{mindev}{The within-node deviance must be at least this times that
    of the root node for the node to be split.}
}
\description{
  A utility function for use with the \code{control} argument of \code{tree}.
}
\details{ 
  This function produces default values of \code{mincut} and
  \code{minsize}, and ensures that \code{mincut} is at most half
  \code{minsize}.

  To produce a tree that fits the data perfectly, set \code{mindev = 0}
  and \code{minsize = 2}, if the limit on tree depth allows such a tree.
}
\value{
  A list:
  \item{mincut}{The maximum of the input or default mincut and 1}
  \item{minsize}{The maximum of the input or default minsize and 2.}
  \item{nmax}{A estimate of the maximum number of nodes that might be grown.}
  \item{nobs}{The input \code{nobs}.}
}
\note{
  The interpretation of \code{mindev} given here is that of Chambers and
  Hastie (1992, p. 415), and apparently not what is actually implemented
  in S.  It seems S uses an absolute bound.
}
\author{B. D. Ripley}

\seealso{\code{\link{tree}}}

\keyword{tree}

\eof
\name{tree.screens}
\title{Split Screen for Plotting Trees}
\usage{
tree.screens(figs, screen.arg = 0, ...)
}
\alias{tree.screens}
\arguments{
  \item{figs}{A specification of the split of the screen. See
    \code{\link{split.screen}} for the allowed forms.}
  \item{screen.arg}{the screen to divide, by default the whole display area.}
  \item{\dots}{plot parameters to be passed to \code{par}.}
}
\description{
  Splits the screen in a way suitable for using \code{tile.tree}.
}
\value{
  A vector of screen numbers for the newly-created screens.
}
\author{B. D. Ripley}

\seealso{\code{\link{tile.tree}}, \code{\link{split.screen}}}

\examples{
library(MASS)
data(fgl)
fgl.tr <- tree(type ~ ., fgl)
summary(fgl.tr)
plot(fgl.tr);  text(fgl.tr, all=TRUE, cex=0.5)
fgl.tr1 <- snip.tree(fgl.tr, node=c(108, 31, 26))
tree.screens()
plot(fgl.tr1)
tile.tree(fgl.tr1, fgl$type)
close.screen(all = TRUE)
}
\keyword{tree}
\keyword{hplot}

\eof
